==> v3.9.tar.gz: privacyguides.org/docs/news-aggregators.md <==
---
title: "News Aggregators"
icon: material/rss
description: These news aggregator clients let you keep up with your favorite blogs and news sites using internet standards like RSS.
---

A [news aggregator](https://en.wikipedia.org/wiki/News_aggregator) is a way to keep up with your favorite blogs and news sites.

## Aggregator clients

### Akregator

!!! recommendation

    ![Akregator logo](assets/img/news-aggregators/akregator.svg){ align=right }

    **Akregator** is a news feed reader that is a part of the [KDE](https://kde.org) project. It comes with a fast search, advanced archiving functionality and an internal browser for easy news reading.

    [:octicons-home-16: Homepage](https://apps.kde.org/akregator){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://kde.org/privacypolicy-apps){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://docs.kde.org/?application=akregator){ .card-link title=Documentation}
    [:octicons-code-16:](https://invent.kde.org/pim/akregator){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://kde.org/community/donations/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-flathub: Flathub](https://flathub.org/apps/details/org.kde.akregator)

### Feeder

!!! recommendation

    ![Feeder logo](assets/img/news-aggregators/feeder.png){ align=right }

    **Feeder** is a modern RSS client for Android that has many [features](https://gitlab.com/spacecowboy/Feeder#features) and works well with folders of RSS feeds. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-repo-16: Repository](https://gitlab.com/spacecowboy/Feeder){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.com/spacecowboy/Feeder){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://ko-fi.com/spacecowboy){ .card-link title=Contribute }

    ??? downloads

        - [:simple-googleplay: Google Play](https://play.google.com/store/apps/details?id=com.nononsenseapps.feeder.play)

### Fluent Reader

!!! recommendation

    ![Fluent Reader logo](assets/img/news-aggregators/fluent-reader.svg){ align=right }

    **Fluent Reader** is a secure cross-platform news aggregator that has useful privacy features such as deletion of cookies on exit, strict [content security policies (CSP)](https://en.wikipedia.org/wiki/Content_Security_Policy) and proxy support, meaning you can use it over [Tor](tor.md).

    [:octicons-home-16: Homepage](https://hyliu.me/fluent-reader){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://github.com/yang991178/fluent-reader/wiki/Privacy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://github.com/yang991178/fluent-reader/wiki/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/yang991178/fluent-reader){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://github.com/sponsors/yang991178){ .card-link title=Contribute }

    ??? downloads

        - [:simple-windows11: Windows](https://hyliu.me/fluent-reader)
        - [:simple-appstore: App Store](https://apps.apple.com/app/id1520907427)

### GNOME Feeds

!!! recommendation

    ![GNOME Feeds logo](assets/img/news-aggregators/gfeeds.svg){ align=right }

    **GNOME Feeds** is an [RSS](https://en.wikipedia.org/wiki/RSS) and [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) news reader for [GNOME](https://www.gnome.org). It has a simple interface and is quite fast.

    [:octicons-home-16: Homepage](https://gfeeds.gabmus.org){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.gnome.org/World/gfeeds){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://liberapay.com/gabmus/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-linux: Linux](https://gfeeds.gabmus.org/#install)
        - [:simple-flathub: Flathub](https://flathub.org/apps/details/org.gabmus.gfeeds)

### Miniflux

!!! recommendation

    ![Miniflux logo](assets/img/news-aggregators/miniflux.svg#only-light){ align=right }
    ![Miniflux logo](assets/img/news-aggregators/miniflux-dark.svg#only-dark){ align=right }

    **Miniflux** is a web-based news aggregator that you can self-host. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-home-16: Homepage](https://miniflux.app){ .md-button .md-button--primary }
    [:octicons-info-16:](https://miniflux.app/docs/index.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/miniflux/v2){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://miniflux.app/#donations){ .card-link title=Contribute }

### NetNewsWire

!!! recommendation

    ![NetNewsWire logo](assets/img/news-aggregators/netnewswire.png){ align=right }

    **NetNewsWire** a free and open-source feed reader for macOS and iOS with a focus on a native design and feature set. It supports the typical feed formats alongside built-in support for Twitter and Reddit feeds.

    [:octicons-home-16: Homepage](https://netnewswire.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://netnewswire.com/privacypolicy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://netnewswire.com/help/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/Ranchero-Software/NetNewsWire){ .card-link title="Source Code" }

    ??? downloads

        - [:simple-appstore: App Store](https://apps.apple.com/us/app/netnewswire-rss-reader/id1480640210)
        - [:simple-apple: macOS](https://netnewswire.com)

### Newsboat

!!! recommendation

    ![Newsboat logo](assets/img/news-aggregators/newsboat.svg){ align=right }

    **Newsboat** is an RSS/Atom feed reader for the text console. It's an actively maintained fork of [Newsbeuter](https://en.wikipedia.org/wiki/Newsbeuter). It is very lightweight, and ideal for use over [Secure Shell](https://en.wikipedia.org/wiki/Secure_Shell).

    [:octicons-home-16: Homepage](https://newsboat.org){ .md-button .md-button--primary }
    [:octicons-info-16:](https://newsboat.org/releases/2.27/docs/newsboat.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/newsboat/newsboat){ .card-link title="Source Code" }

## Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Must be open-source software.
- Must operate locally, i.e. must not be a cloud service.

## Social Media RSS Support

Some social media services also support RSS although it's not often advertised.

### Reddit

Reddit allows you to subscribe to subreddits via RSS.

!!! example
    Replace `subreddit_name` with the subreddit you wish to subscribe to.

    ```text
    https://www.reddit.com/r/{{ subreddit_name }}/new/.rss
    ```

### Twitter

Using any of the Nitter [instances](https://github.com/zedeus/nitter/wiki/Instances) you can easily subscribe using RSS.

!!! example
    1. Pick an instance and set `nitter_instance`.
    2. Replace `twitter_account` with the account name.

       ```text
       https://{{ nitter_instance }}/{{ twitter_account }}/rss
       ```

### YouTube

You can subscribe YouTube channels without logging in and associating usage information with your Google Account.

!!! example

    To subscribe to a YouTube channel with an RSS client, first look for your [channel code](https://support.google.com/youtube/answer/6180214), replace `[CHANNEL ID]` below:
    ```text
    https://www.youtube.com/feeds/videos.xml?channel_id=[CHANNEL ID]
    ```

==> v3.12.1.tar.gz: privacyguides.org/docs/news-aggregators.md <==
---
title: "News Aggregators"
icon: material/rss
description: These news aggregator clients let you keep up with your favorite blogs and news sites using internet standards like RSS.
cover: news-aggregators.png
---

A [news aggregator](https://en.wikipedia.org/wiki/News_aggregator) is a way to keep up with your favorite blogs and news sites.

## Aggregator clients

### Akregator

!!! recommendation

    ![Akregator logo](assets/img/news-aggregators/akregator.svg){ align=right }

    **Akregator** is a news feed reader that is a part of the [KDE](https://kde.org) project. It comes with a fast search, advanced archiving functionality and an internal browser for easy news reading.

    [:octicons-home-16: Homepage](https://apps.kde.org/akregator){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://kde.org/privacypolicy-apps){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://docs.kde.org/?application=akregator){ .card-link title=Documentation}
    [:octicons-code-16:](https://invent.kde.org/pim/akregator){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://kde.org/community/donations/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-flathub: Flathub](https://flathub.org/apps/details/org.kde.akregator)

### Feeder

!!! recommendation

    ![Feeder logo](assets/img/news-aggregators/feeder.png){ align=right }

    **Feeder** is a modern RSS client for Android that has many [features](https://gitlab.com/spacecowboy/Feeder#features) and works well with folders of RSS feeds. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-repo-16: Repository](https://gitlab.com/spacecowboy/Feeder){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.com/spacecowboy/Feeder){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://ko-fi.com/spacecowboy){ .card-link title=Contribute }

    ??? downloads

        - [:simple-googleplay: Google Play](https://play.google.com/store/apps/details?id=com.nononsenseapps.feeder.play)

### Fluent Reader

!!! recommendation

    ![Fluent Reader logo](assets/img/news-aggregators/fluent-reader.svg){ align=right }

    **Fluent Reader** is a secure cross-platform news aggregator that has useful privacy features such as deletion of cookies on exit, strict [content security policies (CSP)](https://en.wikipedia.org/wiki/Content_Security_Policy) and proxy support, meaning you can use it over [Tor](tor.md).

    [:octicons-home-16: Homepage](https://hyliu.me/fluent-reader){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://github.com/yang991178/fluent-reader/wiki/Privacy){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://github.com/yang991178/fluent-reader/wiki/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/yang991178/fluent-reader){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://github.com/sponsors/yang991178){ .card-link title=Contribute }

    ??? downloads

        - [:simple-windows11: Windows](https://hyliu.me/fluent-reader)
        - [:simple-appstore: App Store](https://apps.apple.com/app/id1520907427)

### GNOME Feeds

!!! recommendation

    ![GNOME Feeds logo](assets/img/news-aggregators/gfeeds.svg){ align=right }

    **GNOME Feeds** is an [RSS](https://en.wikipedia.org/wiki/RSS) and [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)) news reader for [GNOME](https://www.gnome.org). It has a simple interface and is quite fast.

    [:octicons-home-16: Homepage](https://gfeeds.gabmus.org){ .md-button .md-button--primary }
    [:octicons-code-16:](https://gitlab.gnome.org/World/gfeeds){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://liberapay.com/gabmus/){ .card-link title=Contribute }

    ??? downloads

        - [:simple-linux: Linux](https://gfeeds.gabmus.org/#install)
        - [:simple-flathub: Flathub](https://flathub.org/apps/details/org.gabmus.gfeeds)

### Miniflux

!!! recommendation

    ![Miniflux logo](assets/img/news-aggregators/miniflux.svg#only-light){ align=right }
    ![Miniflux logo](assets/img/news-aggregators/miniflux-dark.svg#only-dark){ align=right }

    **Miniflux** is a web-based news aggregator that you can self-host. It supports [RSS](https://en.wikipedia.org/wiki/RSS), [Atom](https://en.wikipedia.org/wiki/Atom_(Web_standard)), [RDF](https://en.wikipedia.org/wiki/RDF%2FXML) and [JSON Feed](https://en.wikipedia.org/wiki/JSON_Feed).

    [:octicons-home-16: Homepage](https://miniflux.app){ .md-button .md-button--primary }
    [:octicons-info-16:](https://miniflux.app/docs/index.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/miniflux/v2){ .card-link title="Source Code" }
    [:octicons-heart-16:](https://miniflux.app/#donations){ .card-link title=Contribute }

### NetNewsWire

!!! recommendation

    ![NetNewsWire logo](assets/img/news-aggregators/netnewswire.png){ align=right }

    **NetNewsWire** a free and open-source feed reader for macOS and iOS with a focus on a native design and feature set. It supports the typical feed formats alongside built-in support for Reddit feeds.

    [:octicons-home-16: Homepage](https://netnewswire.com/){ .md-button .md-button--primary }
    [:octicons-eye-16:](https://netnewswire.com/privacypolicy.html){ .card-link title="Privacy Policy" }
    [:octicons-info-16:](https://netnewswire.com/help/){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/Ranchero-Software/NetNewsWire){ .card-link title="Source Code" }

    ??? downloads

        - [:simple-appstore: App Store](https://apps.apple.com/us/app/netnewswire-rss-reader/id1480640210)
        - [:simple-apple: macOS](https://netnewswire.com)

### Newsboat

!!! recommendation

    ![Newsboat logo](assets/img/news-aggregators/newsboat.svg){ align=right }

    **Newsboat** is an RSS/Atom feed reader for the text console. It's an actively maintained fork of [Newsbeuter](https://en.wikipedia.org/wiki/Newsbeuter). It is very lightweight, and ideal for use over [Secure Shell](https://en.wikipedia.org/wiki/Secure_Shell).

    [:octicons-home-16: Homepage](https://newsboat.org){ .md-button .md-button--primary }
    [:octicons-info-16:](https://newsboat.org/releases/2.27/docs/newsboat.html){ .card-link title=Documentation}
    [:octicons-code-16:](https://github.com/newsboat/newsboat){ .card-link title="Source Code" }

## Criteria

**Please note we are not affiliated with any of the projects we recommend.** In addition to [our standard criteria](about/criteria.md), we have developed a clear set of requirements to allow us to provide objective recommendations. We suggest you familiarize yourself with this list before choosing to use a project, and conduct your own research to ensure it's the right choice for you.

!!! example "This section is new"

    We are working on establishing defined criteria for every section of our site, and this may be subject to change. If you have any questions about our criteria, please [ask on our forum](https://discuss.privacyguides.net/latest) and don't assume we didn't consider something when making our recommendations if it is not listed here. There are many factors considered and discussed when we recommend a project, and documenting every single one is a work-in-progress.

- Must be open-source software.
- Must operate locally, i.e. must not be a cloud service.

## Social Media RSS Support

Some social media services also support RSS although it's not often advertised.

### Reddit

Reddit allows you to subscribe to subreddits via RSS.

!!! example
    Replace `subreddit_name` with the subreddit you wish to subscribe to.

    ```text
    https://www.reddit.com/r/{{ subreddit_name }}/new/.rss
    ```

### Twitter

Using any of the Nitter [instances](https://github.com/zedeus/nitter/wiki/Instances) you can easily subscribe using RSS.

!!! example
    1. Pick an instance and set `nitter_instance`.
    2. Replace `twitter_account` with the account name.

       ```text
       https://{{ nitter_instance }}/{{ twitter_account }}/rss
       ```

### YouTube

You can subscribe YouTube channels without logging in and associating usage information with your Google Account.

!!! example

    To subscribe to a YouTube channel with an RSS client, first look for your [channel code](https://support.google.com/youtube/answer/6180214), replace `[CHANNEL ID]` below:
    ```text
    https://www.youtube.com/feeds/videos.xml?channel_id=[CHANNEL ID]
    ```
